@@ -29,9 +29,12 @@ class Population:
 
     def breed(self):
         odds = []
+        total_fit = 0
         for i in self.birds:
-            odds.append(i.fitness)
-        odds = softmax(odds)
+            total_fit += i.fitness
+        for i in self.birds:
+            odds.append(i.fitness / (total_fit - i.fitness))
+        print([max(odds), min(odds)])
         
         next_gen = []
         next_gen = sorted(self.birds, key=lambda x: x.fitness)[-int(np.floor(len(self.birds) * .2)):]
@@ -51,11 +54,12 @@ class Population:
 
     def mutate(self, mutate_r8, radius_ratio):
         for bird in self.birds:
-            for matrix in range(len(bird.matrices)):
-                for row in range(len(bird.matrices[matrix])):
-                    for col in range(len(bird.matrices[matrix][0])):
-                        if np.random.uniform() < mutate_r8:
-                            bird.matrices[matrix][row][col] += np.random.normal(0, 1/np.sqrt(len(bird.matrices[matrix][0])) * radius_ratio, 1)[0]
+            if np.random.uniform() < .96:
+                for matrix in range(len(bird.matrices)):
+                    for row in range(len(bird.matrices[matrix])):
+                        for col in range(len(bird.matrices[matrix][0])):
+                            if np.random.uniform() < mutate_r8:
+                                bird.matrices[matrix][row][col] += np.random.normal(0, 1/np.sqrt(len(bird.matrices[matrix][0])) * radius_ratio, 1)[0]
         
 
 
